==> haskell-drbg-0.5.5-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-KZrlh16wD0B2j3zNfIlKbm
key: DRBG-0.5.5-KZrlh16wD0B2j3zNfIlKbm
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: bce8c14b2041284ab9c86322685530d3
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.4.2/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.4.2/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-KZrlh16wD0B2j3zNfIlKbm
depends:
    base-4.11.1.0 cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    bytestring-0.10.8.2 prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    crypto-api-0.13.3-Fw5IAYlKa1XA1lGK6AaZRl
    cryptohash-cryptoapi-0.1.4-InxXk5XPauKGKA54JZzGjz
    parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE mtl-2.2.2
    cipher-aes128-0.7.0.3-H93VaE6cqJa6ftmef3D9DH
    entropy-0.3.8-3mbkpbP1M3JfJE5J1Kx22
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=ee76325aa2f8c8394749fe66ba154623
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI=17051f81581f5e6482c365c1a780b7ab
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=9cfccdbb0f679fbc0a04182b333a8da7
             crypto-api-0.13.3-Fw5IAYlKa1XA1lGK6AaZRl=432fed1db2b4bd4e84b728353d25470d
             cryptohash-cryptoapi-0.1.4-InxXk5XPauKGKA54JZzGjz=74f1a6c1e12f5c4b6dc27ce1cce0738e
             parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE=5acc896b5484fd32116fb868fccee170
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
             cipher-aes128-0.7.0.3-H93VaE6cqJa6ftmef3D9DH=9fc6c65a484b7b80536b382dad35cb0c
             entropy-0.3.8-3mbkpbP1M3JfJE5J1Kx22=6b12e6710669055c7d543d98e3a5ebd3
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-drbg-0.5.5-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-KW2nD7TcCaK6t5fMtDm50G
key: DRBG-0.5.5-KW2nD7TcCaK6t5fMtDm50G
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: 78cc25ee3b123c18f88fb0be02c408a2
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.4.2/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.4.2/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-KW2nD7TcCaK6t5fMtDm50G
depends:
    base-4.11.1.0 cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    bytestring-0.10.8.2 prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU
    cryptohash-cryptoapi-0.1.4-6PeCJKRzcfn9OCe9wgblGE
    parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE mtl-2.2.2
    cipher-aes128-0.7.0.3-Ejqf5GqoGyXDPeh4UB2Az1
    entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=ee76325aa2f8c8394749fe66ba154623
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             prettyclass-1.0.0.0-Df5qLRMS9VqBFe7pBmacOI=17051f81581f5e6482c365c1a780b7ab
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=9cfccdbb0f679fbc0a04182b333a8da7
             crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU=3cbc3f55c1cbff1ecf023a67e630f88b
             cryptohash-cryptoapi-0.1.4-6PeCJKRzcfn9OCe9wgblGE=8eea3b2223897262ffc0dc6348a6c17e
             parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE=5acc896b5484fd32116fb868fccee170
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
             cipher-aes128-0.7.0.3-Ejqf5GqoGyXDPeh4UB2Az1=12adb31e7218b1ba28cbd409a159a756
             entropy-0.4.1.1-FmBdJKRG6hQDsYzBhT7c6v=fabe753d25a54bcc6723351b46e95c60
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
